@@ -86,13 +86,13 @@ setMethod("c", "XVector",
 setMethod("extractROWS", "XVector",
     function(x, i)
     {
-        i <- extractROWS(setNames(seq_along(x), names(x)), i)
+        i <- normalizeSingleBracketSubscript(i, x)
         new_shared <- SharedVector(class(x@shared), length=length(i))
         SharedVector.copy(new_shared, x@offset + i, src=x@shared)
         x@shared <- new_shared
         x@offset <- 0L
         x@length <- length(new_shared)
-        mcols(x) <- mcols(x)[i, , drop=FALSE]
+        x@elementMetadata <- extractROWS(x@elementMetadata, i)
         x
     }
 )
